FlushMetrics

Struct FlushMetrics 

pub struct FlushMetrics {
Show 28 fields pub batch_count: u64, pub sync_batch_count: u64, pub write_request_count: u64, pub write_bytes: u64, pub callback_count: u64, pub group_wait_count: u64, pub group_wait_us: u64, pub group_wait_max_us: u64, pub queued_wait_us: u64, pub queued_wait_max_us: u64, pub write_us: u64, pub write_max_us: u64, pub sync_us: u64, pub sync_max_us: u64, pub batch_us: u64, pub batch_max_us: u64, pub batch_size_max: u64, pub batch_bytes_max: u64, pub last_batch_size: u64, pub last_batch_bytes: u64, pub last_callback_count: u64, pub last_sync_us: u64, pub last_queued_wait_max_us: u64, pub group_wait_percentiles: FlushLatencyPercentiles, pub queued_wait_percentiles: FlushLatencyPercentiles, pub write_percentiles: FlushLatencyPercentiles, pub sync_percentiles: FlushLatencyPercentiles, pub batch_percentiles: FlushLatencyPercentiles,
}
Aggregated flush worker metrics.

Fields

batch_count: u64

Number of write batches processed by the flush worker.

sync_batch_count: u64

Number of batches that required a filesystem sync.

write_request_count: u64

Number of write requests included in all batches.

write_bytes: u64

Total bytes written by the flush worker.

callback_count: u64

Number of callbacks sent after write batches.

group_wait_count: u64

Number of times the flush worker intentionally waited for batching.

group_wait_us: u64

Total intentional group-commit wait time, in microseconds.

group_wait_max_us: u64

Maximum intentional group-commit wait time, in microseconds.

queued_wait_us: u64

Total request queue wait before a batch starts writing, in microseconds.

queued_wait_max_us: u64

Maximum request queue wait before a batch starts writing, in microseconds.

write_us: u64

Total file write time, in microseconds.

write_max_us: u64

Maximum file write time for one batch, in microseconds.

sync_us: u64

Total filesystem sync time, in microseconds.

sync_max_us: u64

Maximum filesystem sync time for one batch, in microseconds.

batch_us: u64

Total batch processing time, in microseconds.

batch_max_us: u64

Maximum batch processing time, in microseconds.

batch_size_max: u64

Largest number of write requests in one batch.

batch_bytes_max: u64

Largest number of bytes written by one batch.

last_batch_size: u64

Number of write requests in the latest batch.

last_batch_bytes: u64

Number of bytes written by the latest batch.

last_callback_count: u64

Number of callbacks sent by the latest batch.

last_sync_us: u64

Filesystem sync duration of the latest batch, in microseconds.

last_queued_wait_max_us: u64

Request queue wait maximum of the latest batch, in microseconds.

group_wait_percentiles: FlushLatencyPercentiles

Intentional group-commit wait latency percentiles, in microseconds.

queued_wait_percentiles: FlushLatencyPercentiles

Per-batch max request queue wait latency percentiles, in microseconds.

write_percentiles: FlushLatencyPercentiles

File write latency percentiles, in microseconds.

sync_percentiles: FlushLatencyPercentiles

Filesystem sync latency percentiles, in microseconds.

batch_percentiles: FlushLatencyPercentiles

Whole batch processing latency percentiles, in microseconds.