pub struct FlushMetrics {Show 28 fields
pub batch_count: u64,
pub sync_batch_count: u64,
pub write_request_count: u64,
pub write_bytes: u64,
pub callback_count: u64,
pub group_wait_count: u64,
pub group_wait_us: u64,
pub group_wait_max_us: u64,
pub queued_wait_us: u64,
pub queued_wait_max_us: u64,
pub write_us: u64,
pub write_max_us: u64,
pub sync_us: u64,
pub sync_max_us: u64,
pub batch_us: u64,
pub batch_max_us: u64,
pub batch_size_max: u64,
pub batch_bytes_max: u64,
pub last_batch_size: u64,
pub last_batch_bytes: u64,
pub last_callback_count: u64,
pub last_sync_us: u64,
pub last_queued_wait_max_us: u64,
pub group_wait_percentiles: FlushLatencyPercentiles,
pub queued_wait_percentiles: FlushLatencyPercentiles,
pub write_percentiles: FlushLatencyPercentiles,
pub sync_percentiles: FlushLatencyPercentiles,
pub batch_percentiles: FlushLatencyPercentiles,
}Expand description
Aggregated flush worker metrics.
Fields
batch_count: u64Number of write batches processed by the flush worker.
sync_batch_count: u64Number of batches that required a filesystem sync.
write_request_count: u64Number of write requests included in all batches.
write_bytes: u64Total bytes written by the flush worker.
callback_count: u64Number of callbacks sent after write batches.
group_wait_count: u64Number of times the flush worker intentionally waited for batching.
group_wait_us: u64Total intentional group-commit wait time, in microseconds.
group_wait_max_us: u64Maximum intentional group-commit wait time, in microseconds.
queued_wait_us: u64Total request queue wait before a batch starts writing, in microseconds.
queued_wait_max_us: u64Maximum request queue wait before a batch starts writing, in microseconds.
write_us: u64Total file write time, in microseconds.
write_max_us: u64Maximum file write time for one batch, in microseconds.
sync_us: u64Total filesystem sync time, in microseconds.
sync_max_us: u64Maximum filesystem sync time for one batch, in microseconds.
batch_us: u64Total batch processing time, in microseconds.
batch_max_us: u64Maximum batch processing time, in microseconds.
batch_size_max: u64Largest number of write requests in one batch.
batch_bytes_max: u64Largest number of bytes written by one batch.
last_batch_size: u64Number of write requests in the latest batch.
last_batch_bytes: u64Number of bytes written by the latest batch.
last_callback_count: u64Number of callbacks sent by the latest batch.
last_sync_us: u64Filesystem sync duration of the latest batch, in microseconds.
last_queued_wait_max_us: u64Request queue wait maximum of the latest batch, in microseconds.
group_wait_percentiles: FlushLatencyPercentilesIntentional group-commit wait latency percentiles, in microseconds.
queued_wait_percentiles: FlushLatencyPercentilesPer-batch max request queue wait latency percentiles, in microseconds.
write_percentiles: FlushLatencyPercentilesFile write latency percentiles, in microseconds.
sync_percentiles: FlushLatencyPercentilesFilesystem sync latency percentiles, in microseconds.
batch_percentiles: FlushLatencyPercentilesWhole batch processing latency percentiles, in microseconds.